setwd("~/Google Drive File Stream/My Drive/SPEC Summer 2020/Training Data Science/0 Training Data")

library(ggplot2)
library(tidyverse)
library(foreign)

dat <- read.csv("wdi_cleaned.csv", stringsAsFactors = TRUE)

str(dat)

summary(dat$electricity_pop)

ggplot(dat, aes(electricity_pop)) + geom_histogram()

ggplot(dat, aes(electricity_pop)) + geom_histogram(bins = 5) + coord_flip()

ggplot(dat, aes(electricity_pop)) + geom_histogram(bins = 100)

ggplot(dat, aes(electricity_pop)) + geom_density()

ggplot(dat, aes(x = electricity_pop)) + geom_line(stat = "density")

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") 

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))


ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density", color = "#2727ff") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density", color = "#2727ff", linetype = "dotdash") + 
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density", color = "#2727ff", size = 5) +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density", color = "#2727ff", size = 3, alpha = 0.3) + 
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))

table(dat$year[!is.na(dat$electricity_pop)])

ggplot(dat, aes(x = electricity_pop, color = factor(year))) +
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))

ggplot(dat, aes(x = electricity_pop, color = factor(year))) +
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03)) + 
  scale_color_manual(values = c("Red", "Yellow","Black"), name = "Year")

ggplot(dat, aes(x = electricity_pop, linetype = factor(year), color = factor(year))) + 
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03))+ 
  scale_color_manual(values = c("Red", "Yellow","Black"), name = "Year")

ggplot(dat, aes(x = electricity_pop)) +
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity",
       y = "Density") + coord_cartesian(ylim = c(0, 0.03)) + facet_wrap(~ year)

ggplot(subset(dat, year %in% c(2000, 2010, 2012)), aes(x = electricity_pop)) + 
  geom_line(stat = "density") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Percentage of the population with access to electricity", y = "Density") +
  coord_cartesian(ylim = c(0, 0.03)) + facet_wrap(~ year)

ggplot(subset(dat, year %in% c(2000, 2010, 2012)), aes(x = factor(year), y = electricity_pop)) +
  geom_boxplot() +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "Year",
       y = "Percentage of the population with access to electricity")

ggplot(subset(dat, year %in% c(2000, 2010, 2012)), aes(x = factor(year), y = electricity_pop)) +
  geom_boxplot(width = 0.3, color = "firebrick4", fill = "Black") + 
  labs(title = "Distribution of access to electricity across all countries",
  subtitle = "Data source: World Development Indicators",
  x = "Year",
  y = "Percentage of the population with access to electricity")
ggplot(subset(dat, year %in% c(2000, 2010, 2012)), aes(x = factor(year), y = electricity_pop)) +
  geom_boxplot(width = 0.3, color = "firebrick4", fill = "firebrick1") + labs(title = "Distribution of access to electricity across all countries",
                                                                              subtitle = "Data source: World Development Indicators",
                                                                              x = "Year",
                                                                              y = "Percentage of the population with access to electricity") +
  coord_flip()
ggsave("boxplot_horizontal.png", width = 6, height = 3, dpi = 400)





