##############################################
# Created by: Sara Lowe, 18 June 2020
# Most recently edited on: 18 June 2020

# Task: Write an R script that works through 
# the Data Visualization I walkthrough. We're 
# working with ggplot2 now! 
##############################################

setwd("~/Google Drive File Stream/My Drive/SPEC Summer 2020 (1)/Training Data Science/0 Training Data/trainingoutput")
getwd()
rm(list=ls())
# install packages 
library(foreign)
library(dplyr)
library(tidyr)
install.packages("ggplot2")
library(ggplot2)
sessionInfo()

# load data 
library(readr)
data <- read.csv("~/Google Drive File Stream/My Drive/SPEC Summer 2020 (1)/Training Data Science/0 Training Data/wdi_cleaned_part1.csv", stringsAsFactors = F)
str(data)

# summarize electricity data 
summary(data$electricity_pop)

# set up ggplot 
ggplot(data = data, aes(x = electricity_pop))+
  geom_histogram()

# run the histogram again, but pick a better binwidth (25 instead of 30)
ggplot(data = data, aes(x = electricity_pop))+
  geom_histogram(bins = 25)

# try making a density plot using geom_line
ggplot(data = data, aes(x = electricity_pop))+ 
  geom_density()
# this next thing is the same but we're using geom_line instead 
ggplot(data = data, aes(x = electricity_pop))+ 
  geom_line(stat = "density")

elec_hist<- ggplot(data = data, aes(x = electricity_pop))+
  geom_density(fill = "deeppink1")

# labeling title, subtitle, and axes titles
ggplot(data, aes(x = electricity_pop))+
  geom_line(stat = "density",
            color = "#2727ff",
            size = 2)+
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: WDI",
       x = "percentage of the population with access to electricity",
       y = "density") +
       coord_cartesian(ylim = c(0, 0.3))
       
# make table of 2000, 2010, 2012
table(data$year[!is.na(data$electricity_pop)])

ggplot(data, aes(x = electricity_pop,
                 color = factor(year)))+
  geom_line(stat = "density")+
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: WDI",
       x = "percentage of the population with access to electricity",
       y = "density") +
  coord_cartesian(ylim = c(0, 0.03))+
  scale_color_manual(values = c("8c00ff",
                                "#ff8c00",
                                "#00ff8c"),
                     name = "Year")

ggplot(subset(data, year %in% c(2000, 2010, 2012), aes(x = electricity_pop,
                 color = factor(year)))+
  geom_line(stat = "density")+
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: WDI",
       x = "percentage of the population with access to electricity",
       y = "density") +
  coord_cartesian(ylim = c(0, 0.03))+
  facet_wrap(~ year)
  
# work on making a boxplot
ggplot(subset(data, year %in% c(2000, 2010, 2012)),
       aes(x = factor(year), y = electricity_pop)) + 
  geom_boxplot() +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "year",
       y = "Percentage of the population with access to electricity")
# run the same plot but change the orientation via coord flip, change color
ggplot(subset(data, year %in% c(2000, 2010, 2012)),
       aes(x = factor(year), y = electricity_pop)) + 
  geom_boxplot(width = 0.3, color = "firebrick4", fill = "firebrick4") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "year",
       y = "Percentage of the population with access to electricity")+
  coord_flip()
# save this as a boxplot 
boxplot<- ggplot(subset(data, year %in% c(2000, 2010, 2012)),
                 aes(x = factor(year), y = electricity_pop)) + 
  geom_boxplot(width = 0.3, color = "firebrick4", fill = "firebrick4") +
  labs(title = "Distribution of access to electricity across all countries",
       subtitle = "Data source: World Development Indicators",
       x = "year",
       y = "Percentage of the population with access to electricity")+
  coord_flip()
ggsave("boxplot_red_horizontal_Sara.png", plot = boxplot, width = 6, 
       height = 3, dpi = 400)

