##################################
# Script by: Ari Kelo
# Project: Data Science Training
# Original Script: June 24, 2020
# Purpose: Walkthrough for Data Management 3 training
# Last modified: June 25, 2020
#################################

rm(list = ls())
library(dplyr)
library(countrycode)

setwd("G:/.shortcut-targets-by-id/1TXk1G5ASoQ-vD7rs4E5dMtNk1W-d1k6m/SPEC Summer 2020/Training Data Science/0 Training Data")
load("IDC_Controls_fortraining.RData")

rents_global <- idc_controls %>%
  group_by(year) %>% #splits data into groups by year 
  dplyr::summarise(natresource_rents_mean = mean(natresource_rents_WDI, na.rm = TRUE))
        # looking at natural resource rents from WDI data and removing all NAs 
        # use package:: to identify a command that may be similar to a command in another package
View(rents_global)
                  
#Calculate global averages and then group_by year
trade_rents_global <- idc_controls %>%
  group_by(year) %>%
  summarise_at(vars(natresource_rents_WDI, trade_WDI), mean, na.rm = T)
View(trade_rents_global)

#vars() = select() except you can use it with another function

#looking at regional averages - we need to mutate() the data to add a region variable
rents_regional <- idc_controls %>%
  mutate(region = countrycode(gwno, "gwn", "region")) %>% #using the countrycode package to add our region variable with the gwno regional classifications
  group_by(region, year) %>% #grouping our data by both region and year
  dplyr::summarise(natresource_rents_mean = mean(natresource_rents_WDI, na.rm = T)) #aggregating so that the output is the global averages of resource rents by year and region
View(rents_regional)

#Summarizing and simplifying
#start by collapsing country-year data into country-decade data
rents_decade <- idc_controls %>%
  mutate(decade = year - year %% 10) %>% # add decade variable (year %% 10 gives us the last digit, then we subtract from the year to get the decade)
  group_by(gwno, decade) %>% #grouping by decade rather than by year
  dplyr::summarise(rents_mean = mean(natresource_rents_WDI, na.rm = T),
                   rents_med = median(natresource_rents_WDI, na.rm = T),
                   rents_max = max(natresource_rents_WDI, na.rm = T),
                   rents_min = min(natresource_rents_WDI, na.rm = T)) #taking the summary statistics for our data by decade
    # %% gives you the remainder (21/10 with whole numbers would give you 1)

#doing the same thing with the global_rents data on trade and resource rents
trade_rents_decade <- idc_controls %>%
  mutate(decade = year - year %% 10) %>%
  group_by(gwno, decade) %>%
  summarise_at(vars(natresource_rents_WDI, trade_WDI), tibble::lst(mean, median, max, min), na.rm = T)

#Making maps
#to make maps, we need a single value per country, so we need to pull out a single cross-sectional year either using base R or dplyr

#base R
idc_2006 <- idc_controls[idc_controls$year == 2006,]
#how to pull a cross-sectional year with dplyr:
# idc_2006 <- idc_controls %>%
  # filter(year == 2006)

#want a dataset with the annual values for some individual countries, one region, and the global average
trade_rents_global$region <- "Global"

#getting regional averages by continent and then filter so we just keep the Americas
trade_rents_americas <- idc_controls %>%
  mutate(region = countrycode(gwno, "gwn", "continent")) %>%
  group_by(region, year) %>%
  summarise_at(vars(natresource_rents_WDI, trade_WDI), mean, na.rm = T) %>%
  filter(region == "Americas")

#Pulling data for US, Canada, and Mexico
idc_sub <- idc_controls %>%
  filter(country %in% c("United States of America", "Canada", "Mexico")) %>%
  select(region = country, year, natresource_rents_WDI, trade_WDI)

#binding all the dataframes into one
df <- idc_sub %>%
  bind_rows(trade_rents_americas) %>%
  bind_rows(trade_rents_global) #here we use bind_rows instead of rbind so that our numbers of variables don't have
